@@ -3,18 +3,21 @@ Main interface for storagegateway service type definitions.
 
 Usage::
 
-    from mypy_boto3.storagegateway.type_defs import ActivateGatewayOutputTypeDef
+    ```python
+    from mypy_boto3_storagegateway.type_defs import AutomaticTapeCreationPolicyInfoTypeDef
 
-    data: ActivateGatewayOutputTypeDef = {...}
+    data: AutomaticTapeCreationPolicyInfoTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,6 +25,29 @@ else:
 
 
 __all__ = (
+    "AutomaticTapeCreationPolicyInfoTypeDef",
+    "AutomaticTapeCreationRuleTypeDef",
+    "CacheAttributesTypeDef",
+    "CachediSCSIVolumeTypeDef",
+    "ChapInfoTypeDef",
+    "DeviceiSCSIAttributesTypeDef",
+    "DiskTypeDef",
+    "FileShareInfoTypeDef",
+    "GatewayInfoTypeDef",
+    "NFSFileShareDefaultsTypeDef",
+    "NFSFileShareInfoTypeDef",
+    "NetworkInterfaceTypeDef",
+    "SMBFileShareInfoTypeDef",
+    "StorediSCSIVolumeTypeDef",
+    "TagTypeDef",
+    "TapeArchiveTypeDef",
+    "TapeInfoTypeDef",
+    "TapeRecoveryPointInfoTypeDef",
+    "TapeTypeDef",
+    "VTLDeviceTypeDef",
+    "VolumeInfoTypeDef",
+    "VolumeRecoveryPointInfoTypeDef",
+    "VolumeiSCSIAttributesTypeDef",
     "ActivateGatewayOutputTypeDef",
     "AddCacheOutputTypeDef",
     "AddTagsToResourceOutputTypeDef",
@@ -39,6 +65,7 @@ __all__ = (
     "CreateStorediSCSIVolumeOutputTypeDef",
     "CreateTapeWithBarcodeOutputTypeDef",
     "CreateTapesOutputTypeDef",
+    "DeleteAutomaticTapeCreationPolicyOutputTypeDef",
     "DeleteBandwidthRateLimitOutputTypeDef",
     "DeleteChapCredentialsOutputTypeDef",
     "DeleteFileShareOutputTypeDef",
@@ -50,51 +77,32 @@ __all__ = (
     "DescribeAvailabilityMonitorTestOutputTypeDef",
     "DescribeBandwidthRateLimitOutputTypeDef",
     "DescribeCacheOutputTypeDef",
-    "VolumeiSCSIAttributesTypeDef",
-    "CachediSCSIVolumeTypeDef",
     "DescribeCachediSCSIVolumesOutputTypeDef",
-    "ChapInfoTypeDef",
     "DescribeChapCredentialsOutputTypeDef",
-    "NetworkInterfaceTypeDef",
-    "TagTypeDef",
     "DescribeGatewayInformationOutputTypeDef",
     "DescribeMaintenanceStartTimeOutputTypeDef",
-    "NFSFileShareDefaultsTypeDef",
-    "NFSFileShareInfoTypeDef",
     "DescribeNFSFileSharesOutputTypeDef",
-    "SMBFileShareInfoTypeDef",
     "DescribeSMBFileSharesOutputTypeDef",
     "DescribeSMBSettingsOutputTypeDef",
     "DescribeSnapshotScheduleOutputTypeDef",
-    "StorediSCSIVolumeTypeDef",
     "DescribeStorediSCSIVolumesOutputTypeDef",
-    "TapeArchiveTypeDef",
     "DescribeTapeArchivesOutputTypeDef",
-    "TapeRecoveryPointInfoTypeDef",
     "DescribeTapeRecoveryPointsOutputTypeDef",
-    "TapeTypeDef",
     "DescribeTapesOutputTypeDef",
     "DescribeUploadBufferOutputTypeDef",
-    "DeviceiSCSIAttributesTypeDef",
-    "VTLDeviceTypeDef",
     "DescribeVTLDevicesOutputTypeDef",
     "DescribeWorkingStorageOutputTypeDef",
     "DetachVolumeOutputTypeDef",
     "DisableGatewayOutputTypeDef",
     "JoinDomainOutputTypeDef",
-    "FileShareInfoTypeDef",
+    "ListAutomaticTapeCreationPoliciesOutputTypeDef",
     "ListFileSharesOutputTypeDef",
-    "GatewayInfoTypeDef",
     "ListGatewaysOutputTypeDef",
-    "DiskTypeDef",
     "ListLocalDisksOutputTypeDef",
     "ListTagsForResourceOutputTypeDef",
-    "TapeInfoTypeDef",
     "ListTapesOutputTypeDef",
     "ListVolumeInitiatorsOutputTypeDef",
-    "VolumeRecoveryPointInfoTypeDef",
     "ListVolumeRecoveryPointsOutputTypeDef",
-    "VolumeInfoTypeDef",
     "ListVolumesOutputTypeDef",
     "NotifyWhenUploadedOutputTypeDef",
     "PaginatorConfigTypeDef",
@@ -108,6 +116,7 @@ __all__ = (
     "ShutdownGatewayOutputTypeDef",
     "StartAvailabilityMonitorTestOutputTypeDef",
     "StartGatewayOutputTypeDef",
+    "UpdateAutomaticTapeCreationPolicyOutputTypeDef",
     "UpdateBandwidthRateLimitOutputTypeDef",
     "UpdateChapCredentialsOutputTypeDef",
     "UpdateGatewayInformationOutputTypeDef",
@@ -120,6 +129,311 @@ __all__ = (
     "UpdateVTLDeviceTypeOutputTypeDef",
 )
 
+AutomaticTapeCreationPolicyInfoTypeDef = TypedDict(
+    "AutomaticTapeCreationPolicyInfoTypeDef",
+    {"AutomaticTapeCreationRules": List["AutomaticTapeCreationRuleTypeDef"], "GatewayARN": str},
+    total=False,
+)
+
+AutomaticTapeCreationRuleTypeDef = TypedDict(
+    "AutomaticTapeCreationRuleTypeDef",
+    {"TapeBarcodePrefix": str, "PoolId": str, "TapeSizeInBytes": int, "MinimumNumTapes": int},
+)
+
+CacheAttributesTypeDef = TypedDict(
+    "CacheAttributesTypeDef", {"CacheStaleTimeoutInSeconds": int}, total=False
+)
+
+CachediSCSIVolumeTypeDef = TypedDict(
+    "CachediSCSIVolumeTypeDef",
+    {
+        "VolumeARN": str,
+        "VolumeId": str,
+        "VolumeType": str,
+        "VolumeStatus": str,
+        "VolumeAttachmentStatus": str,
+        "VolumeSizeInBytes": int,
+        "VolumeProgress": float,
+        "SourceSnapshotId": str,
+        "VolumeiSCSIAttributes": "VolumeiSCSIAttributesTypeDef",
+        "CreatedDate": datetime,
+        "VolumeUsedInBytes": int,
+        "KMSKey": str,
+        "TargetName": str,
+    },
+    total=False,
+)
+
+ChapInfoTypeDef = TypedDict(
+    "ChapInfoTypeDef",
+    {
+        "TargetARN": str,
+        "SecretToAuthenticateInitiator": str,
+        "InitiatorName": str,
+        "SecretToAuthenticateTarget": str,
+    },
+    total=False,
+)
+
+DeviceiSCSIAttributesTypeDef = TypedDict(
+    "DeviceiSCSIAttributesTypeDef",
+    {"TargetARN": str, "NetworkInterfaceId": str, "NetworkInterfacePort": int, "ChapEnabled": bool},
+    total=False,
+)
+
+DiskTypeDef = TypedDict(
+    "DiskTypeDef",
+    {
+        "DiskId": str,
+        "DiskPath": str,
+        "DiskNode": str,
+        "DiskStatus": str,
+        "DiskSizeInBytes": int,
+        "DiskAllocationType": str,
+        "DiskAllocationResource": str,
+        "DiskAttributeList": List[str],
+    },
+    total=False,
+)
+
+FileShareInfoTypeDef = TypedDict(
+    "FileShareInfoTypeDef",
+    {
+        "FileShareType": Literal["NFS", "SMB"],
+        "FileShareARN": str,
+        "FileShareId": str,
+        "FileShareStatus": str,
+        "GatewayARN": str,
+    },
+    total=False,
+)
+
+GatewayInfoTypeDef = TypedDict(
+    "GatewayInfoTypeDef",
+    {
+        "GatewayId": str,
+        "GatewayARN": str,
+        "GatewayType": str,
+        "GatewayOperationalState": str,
+        "GatewayName": str,
+        "Ec2InstanceId": str,
+        "Ec2InstanceRegion": str,
+    },
+    total=False,
+)
+
+NFSFileShareDefaultsTypeDef = TypedDict(
+    "NFSFileShareDefaultsTypeDef",
+    {"FileMode": str, "DirectoryMode": str, "GroupId": int, "OwnerId": int},
+    total=False,
+)
+
+NFSFileShareInfoTypeDef = TypedDict(
+    "NFSFileShareInfoTypeDef",
+    {
+        "NFSFileShareDefaults": "NFSFileShareDefaultsTypeDef",
+        "FileShareARN": str,
+        "FileShareId": str,
+        "FileShareStatus": str,
+        "GatewayARN": str,
+        "KMSEncrypted": bool,
+        "KMSKey": str,
+        "Path": str,
+        "Role": str,
+        "LocationARN": str,
+        "DefaultStorageClass": str,
+        "ObjectACL": Literal[
+            "private",
+            "public-read",
+            "public-read-write",
+            "authenticated-read",
+            "bucket-owner-read",
+            "bucket-owner-full-control",
+            "aws-exec-read",
+        ],
+        "ClientList": List[str],
+        "Squash": str,
+        "ReadOnly": bool,
+        "GuessMIMETypeEnabled": bool,
+        "RequesterPays": bool,
+        "Tags": List["TagTypeDef"],
+        "FileShareName": str,
+        "CacheAttributes": "CacheAttributesTypeDef",
+    },
+    total=False,
+)
+
+NetworkInterfaceTypeDef = TypedDict(
+    "NetworkInterfaceTypeDef",
+    {"Ipv4Address": str, "MacAddress": str, "Ipv6Address": str},
+    total=False,
+)
+
+SMBFileShareInfoTypeDef = TypedDict(
+    "SMBFileShareInfoTypeDef",
+    {
+        "FileShareARN": str,
+        "FileShareId": str,
+        "FileShareStatus": str,
+        "GatewayARN": str,
+        "KMSEncrypted": bool,
+        "KMSKey": str,
+        "Path": str,
+        "Role": str,
+        "LocationARN": str,
+        "DefaultStorageClass": str,
+        "ObjectACL": Literal[
+            "private",
+            "public-read",
+            "public-read-write",
+            "authenticated-read",
+            "bucket-owner-read",
+            "bucket-owner-full-control",
+            "aws-exec-read",
+        ],
+        "ReadOnly": bool,
+        "GuessMIMETypeEnabled": bool,
+        "RequesterPays": bool,
+        "SMBACLEnabled": bool,
+        "AdminUserList": List[str],
+        "ValidUserList": List[str],
+        "InvalidUserList": List[str],
+        "AuditDestinationARN": str,
+        "Authentication": str,
+        "CaseSensitivity": Literal["ClientSpecified", "CaseSensitive"],
+        "Tags": List["TagTypeDef"],
+        "FileShareName": str,
+        "CacheAttributes": "CacheAttributesTypeDef",
+    },
+    total=False,
+)
+
+StorediSCSIVolumeTypeDef = TypedDict(
+    "StorediSCSIVolumeTypeDef",
+    {
+        "VolumeARN": str,
+        "VolumeId": str,
+        "VolumeType": str,
+        "VolumeStatus": str,
+        "VolumeAttachmentStatus": str,
+        "VolumeSizeInBytes": int,
+        "VolumeProgress": float,
+        "VolumeDiskId": str,
+        "SourceSnapshotId": str,
+        "PreservedExistingData": bool,
+        "VolumeiSCSIAttributes": "VolumeiSCSIAttributesTypeDef",
+        "CreatedDate": datetime,
+        "VolumeUsedInBytes": int,
+        "KMSKey": str,
+        "TargetName": str,
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
+
+TapeArchiveTypeDef = TypedDict(
+    "TapeArchiveTypeDef",
+    {
+        "TapeARN": str,
+        "TapeBarcode": str,
+        "TapeCreatedDate": datetime,
+        "TapeSizeInBytes": int,
+        "CompletionTime": datetime,
+        "RetrievedTo": str,
+        "TapeStatus": str,
+        "TapeUsedInBytes": int,
+        "KMSKey": str,
+        "PoolId": str,
+    },
+    total=False,
+)
+
+TapeInfoTypeDef = TypedDict(
+    "TapeInfoTypeDef",
+    {
+        "TapeARN": str,
+        "TapeBarcode": str,
+        "TapeSizeInBytes": int,
+        "TapeStatus": str,
+        "GatewayARN": str,
+        "PoolId": str,
+    },
+    total=False,
+)
+
+TapeRecoveryPointInfoTypeDef = TypedDict(
+    "TapeRecoveryPointInfoTypeDef",
+    {"TapeARN": str, "TapeRecoveryPointTime": datetime, "TapeSizeInBytes": int, "TapeStatus": str},
+    total=False,
+)
+
+TapeTypeDef = TypedDict(
+    "TapeTypeDef",
+    {
+        "TapeARN": str,
+        "TapeBarcode": str,
+        "TapeCreatedDate": datetime,
+        "TapeSizeInBytes": int,
+        "TapeStatus": str,
+        "VTLDevice": str,
+        "Progress": float,
+        "TapeUsedInBytes": int,
+        "KMSKey": str,
+        "PoolId": str,
+    },
+    total=False,
+)
+
+VTLDeviceTypeDef = TypedDict(
+    "VTLDeviceTypeDef",
+    {
+        "VTLDeviceARN": str,
+        "VTLDeviceType": str,
+        "VTLDeviceVendor": str,
+        "VTLDeviceProductIdentifier": str,
+        "DeviceiSCSIAttributes": "DeviceiSCSIAttributesTypeDef",
+    },
+    total=False,
+)
+
+VolumeInfoTypeDef = TypedDict(
+    "VolumeInfoTypeDef",
+    {
+        "VolumeARN": str,
+        "VolumeId": str,
+        "GatewayARN": str,
+        "GatewayId": str,
+        "VolumeType": str,
+        "VolumeSizeInBytes": int,
+        "VolumeAttachmentStatus": str,
+    },
+    total=False,
+)
+
+VolumeRecoveryPointInfoTypeDef = TypedDict(
+    "VolumeRecoveryPointInfoTypeDef",
+    {
+        "VolumeARN": str,
+        "VolumeSizeInBytes": int,
+        "VolumeUsageInBytes": int,
+        "VolumeRecoveryPointTime": str,
+    },
+    total=False,
+)
+
+VolumeiSCSIAttributesTypeDef = TypedDict(
+    "VolumeiSCSIAttributesTypeDef",
+    {
+        "TargetARN": str,
+        "NetworkInterfaceId": str,
+        "NetworkInterfacePort": int,
+        "LunNumber": int,
+        "ChapEnabled": bool,
+    },
+    total=False,
+)
+
 ActivateGatewayOutputTypeDef = TypedDict(
     "ActivateGatewayOutputTypeDef", {"GatewayARN": str}, total=False
 )
@@ -190,6 +504,10 @@ CreateTapesOutputTypeDef = TypedDict(
     "CreateTapesOutputTypeDef", {"TapeARNs": List[str]}, total=False
 )
 
+DeleteAutomaticTapeCreationPolicyOutputTypeDef = TypedDict(
+    "DeleteAutomaticTapeCreationPolicyOutputTypeDef", {"GatewayARN": str}, total=False
+)
+
 DeleteBandwidthRateLimitOutputTypeDef = TypedDict(
     "DeleteBandwidthRateLimitOutputTypeDef", {"GatewayARN": str}, total=False
 )
@@ -248,67 +566,18 @@ DescribeCacheOutputTypeDef = TypedDict(
     total=False,
 )
 
-VolumeiSCSIAttributesTypeDef = TypedDict(
-    "VolumeiSCSIAttributesTypeDef",
-    {
-        "TargetARN": str,
-        "NetworkInterfaceId": str,
-        "NetworkInterfacePort": int,
-        "LunNumber": int,
-        "ChapEnabled": bool,
-    },
-    total=False,
-)
-
-CachediSCSIVolumeTypeDef = TypedDict(
-    "CachediSCSIVolumeTypeDef",
-    {
-        "VolumeARN": str,
-        "VolumeId": str,
-        "VolumeType": str,
-        "VolumeStatus": str,
-        "VolumeAttachmentStatus": str,
-        "VolumeSizeInBytes": int,
-        "VolumeProgress": float,
-        "SourceSnapshotId": str,
-        "VolumeiSCSIAttributes": VolumeiSCSIAttributesTypeDef,
-        "CreatedDate": datetime,
-        "VolumeUsedInBytes": int,
-        "KMSKey": str,
-        "TargetName": str,
-    },
-    total=False,
-)
-
 DescribeCachediSCSIVolumesOutputTypeDef = TypedDict(
     "DescribeCachediSCSIVolumesOutputTypeDef",
-    {"CachediSCSIVolumes": List[CachediSCSIVolumeTypeDef]},
-    total=False,
-)
-
-ChapInfoTypeDef = TypedDict(
-    "ChapInfoTypeDef",
-    {
-        "TargetARN": str,
-        "SecretToAuthenticateInitiator": str,
-        "InitiatorName": str,
-        "SecretToAuthenticateTarget": str,
-    },
+    {"CachediSCSIVolumes": List["CachediSCSIVolumeTypeDef"]},
     total=False,
 )
 
 DescribeChapCredentialsOutputTypeDef = TypedDict(
-    "DescribeChapCredentialsOutputTypeDef", {"ChapCredentials": List[ChapInfoTypeDef]}, total=False
-)
-
-NetworkInterfaceTypeDef = TypedDict(
-    "NetworkInterfaceTypeDef",
-    {"Ipv4Address": str, "MacAddress": str, "Ipv6Address": str},
+    "DescribeChapCredentialsOutputTypeDef",
+    {"ChapCredentials": List["ChapInfoTypeDef"]},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
-
 DescribeGatewayInformationOutputTypeDef = TypedDict(
     "DescribeGatewayInformationOutputTypeDef",
     {
@@ -317,16 +586,17 @@ DescribeGatewayInformationOutputTypeDef = TypedDict(
         "GatewayName": str,
         "GatewayTimezone": str,
         "GatewayState": str,
-        "GatewayNetworkInterfaces": List[NetworkInterfaceTypeDef],
+        "GatewayNetworkInterfaces": List["NetworkInterfaceTypeDef"],
         "GatewayType": str,
         "NextUpdateAvailabilityDate": str,
         "LastSoftwareUpdate": str,
         "Ec2InstanceId": str,
         "Ec2InstanceRegion": str,
-        "Tags": List[TagTypeDef],
+        "Tags": List["TagTypeDef"],
         "VPCEndpoint": str,
         "CloudWatchLogGroupARN": str,
         "HostEnvironment": Literal["VMWARE", "HYPER-V", "EC2", "KVM", "OTHER"],
+        "EndpointType": str,
     },
     total=False,
 )
@@ -344,89 +614,15 @@ DescribeMaintenanceStartTimeOutputTypeDef = TypedDict(
     total=False,
 )
 
-NFSFileShareDefaultsTypeDef = TypedDict(
-    "NFSFileShareDefaultsTypeDef",
-    {"FileMode": str, "DirectoryMode": str, "GroupId": int, "OwnerId": int},
-    total=False,
-)
-
-NFSFileShareInfoTypeDef = TypedDict(
-    "NFSFileShareInfoTypeDef",
-    {
-        "NFSFileShareDefaults": NFSFileShareDefaultsTypeDef,
-        "FileShareARN": str,
-        "FileShareId": str,
-        "FileShareStatus": str,
-        "GatewayARN": str,
-        "KMSEncrypted": bool,
-        "KMSKey": str,
-        "Path": str,
-        "Role": str,
-        "LocationARN": str,
-        "DefaultStorageClass": str,
-        "ObjectACL": Literal[
-            "private",
-            "public-read",
-            "public-read-write",
-            "authenticated-read",
-            "bucket-owner-read",
-            "bucket-owner-full-control",
-            "aws-exec-read",
-        ],
-        "ClientList": List[str],
-        "Squash": str,
-        "ReadOnly": bool,
-        "GuessMIMETypeEnabled": bool,
-        "RequesterPays": bool,
-        "Tags": List[TagTypeDef],
-    },
-    total=False,
-)
-
 DescribeNFSFileSharesOutputTypeDef = TypedDict(
     "DescribeNFSFileSharesOutputTypeDef",
-    {"NFSFileShareInfoList": List[NFSFileShareInfoTypeDef]},
-    total=False,
-)
-
-SMBFileShareInfoTypeDef = TypedDict(
-    "SMBFileShareInfoTypeDef",
-    {
-        "FileShareARN": str,
-        "FileShareId": str,
-        "FileShareStatus": str,
-        "GatewayARN": str,
-        "KMSEncrypted": bool,
-        "KMSKey": str,
-        "Path": str,
-        "Role": str,
-        "LocationARN": str,
-        "DefaultStorageClass": str,
-        "ObjectACL": Literal[
-            "private",
-            "public-read",
-            "public-read-write",
-            "authenticated-read",
-            "bucket-owner-read",
-            "bucket-owner-full-control",
-            "aws-exec-read",
-        ],
-        "ReadOnly": bool,
-        "GuessMIMETypeEnabled": bool,
-        "RequesterPays": bool,
-        "SMBACLEnabled": bool,
-        "AdminUserList": List[str],
-        "ValidUserList": List[str],
-        "InvalidUserList": List[str],
-        "Authentication": str,
-        "Tags": List[TagTypeDef],
-    },
+    {"NFSFileShareInfoList": List["NFSFileShareInfoTypeDef"]},
     total=False,
 )
 
 DescribeSMBFileSharesOutputTypeDef = TypedDict(
     "DescribeSMBFileSharesOutputTypeDef",
-    {"SMBFileShareInfoList": List[SMBFileShareInfoTypeDef]},
+    {"SMBFileShareInfoList": List["SMBFileShareInfoTypeDef"]},
     total=False,
 )
 
@@ -460,65 +656,20 @@ DescribeSnapshotScheduleOutputTypeDef = TypedDict(
         "RecurrenceInHours": int,
         "Description": str,
         "Timezone": str,
-        "Tags": List[TagTypeDef],
-    },
-    total=False,
-)
-
-StorediSCSIVolumeTypeDef = TypedDict(
-    "StorediSCSIVolumeTypeDef",
-    {
-        "VolumeARN": str,
-        "VolumeId": str,
-        "VolumeType": str,
-        "VolumeStatus": str,
-        "VolumeAttachmentStatus": str,
-        "VolumeSizeInBytes": int,
-        "VolumeProgress": float,
-        "VolumeDiskId": str,
-        "SourceSnapshotId": str,
-        "PreservedExistingData": bool,
-        "VolumeiSCSIAttributes": VolumeiSCSIAttributesTypeDef,
-        "CreatedDate": datetime,
-        "VolumeUsedInBytes": int,
-        "KMSKey": str,
-        "TargetName": str,
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
 
 DescribeStorediSCSIVolumesOutputTypeDef = TypedDict(
     "DescribeStorediSCSIVolumesOutputTypeDef",
-    {"StorediSCSIVolumes": List[StorediSCSIVolumeTypeDef]},
-    total=False,
-)
-
-TapeArchiveTypeDef = TypedDict(
-    "TapeArchiveTypeDef",
-    {
-        "TapeARN": str,
-        "TapeBarcode": str,
-        "TapeCreatedDate": datetime,
-        "TapeSizeInBytes": int,
-        "CompletionTime": datetime,
-        "RetrievedTo": str,
-        "TapeStatus": str,
-        "TapeUsedInBytes": int,
-        "KMSKey": str,
-        "PoolId": str,
-    },
+    {"StorediSCSIVolumes": List["StorediSCSIVolumeTypeDef"]},
     total=False,
 )
 
 DescribeTapeArchivesOutputTypeDef = TypedDict(
     "DescribeTapeArchivesOutputTypeDef",
-    {"TapeArchives": List[TapeArchiveTypeDef], "Marker": str},
-    total=False,
-)
-
-TapeRecoveryPointInfoTypeDef = TypedDict(
-    "TapeRecoveryPointInfoTypeDef",
-    {"TapeARN": str, "TapeRecoveryPointTime": datetime, "TapeSizeInBytes": int, "TapeStatus": str},
+    {"TapeArchives": List["TapeArchiveTypeDef"], "Marker": str},
     total=False,
 )
 
@@ -526,31 +677,14 @@ DescribeTapeRecoveryPointsOutputTypeDef = TypedDict(
     "DescribeTapeRecoveryPointsOutputTypeDef",
     {
         "GatewayARN": str,
-        "TapeRecoveryPointInfos": List[TapeRecoveryPointInfoTypeDef],
+        "TapeRecoveryPointInfos": List["TapeRecoveryPointInfoTypeDef"],
         "Marker": str,
     },
     total=False,
 )
 
-TapeTypeDef = TypedDict(
-    "TapeTypeDef",
-    {
-        "TapeARN": str,
-        "TapeBarcode": str,
-        "TapeCreatedDate": datetime,
-        "TapeSizeInBytes": int,
-        "TapeStatus": str,
-        "VTLDevice": str,
-        "Progress": float,
-        "TapeUsedInBytes": int,
-        "KMSKey": str,
-        "PoolId": str,
-    },
-    total=False,
-)
-
 DescribeTapesOutputTypeDef = TypedDict(
-    "DescribeTapesOutputTypeDef", {"Tapes": List[TapeTypeDef], "Marker": str}, total=False
+    "DescribeTapesOutputTypeDef", {"Tapes": List["TapeTypeDef"], "Marker": str}, total=False
 )
 
 DescribeUploadBufferOutputTypeDef = TypedDict(
@@ -564,27 +698,9 @@ DescribeUploadBufferOutputTypeDef = TypedDict(
     total=False,
 )
 
-DeviceiSCSIAttributesTypeDef = TypedDict(
-    "DeviceiSCSIAttributesTypeDef",
-    {"TargetARN": str, "NetworkInterfaceId": str, "NetworkInterfacePort": int, "ChapEnabled": bool},
-    total=False,
-)
-
-VTLDeviceTypeDef = TypedDict(
-    "VTLDeviceTypeDef",
-    {
-        "VTLDeviceARN": str,
-        "VTLDeviceType": str,
-        "VTLDeviceVendor": str,
-        "VTLDeviceProductIdentifier": str,
-        "DeviceiSCSIAttributes": DeviceiSCSIAttributesTypeDef,
-    },
-    total=False,
-)
-
 DescribeVTLDevicesOutputTypeDef = TypedDict(
     "DescribeVTLDevicesOutputTypeDef",
-    {"GatewayARN": str, "VTLDevices": List[VTLDeviceTypeDef], "Marker": str},
+    {"GatewayARN": str, "VTLDevices": List["VTLDeviceTypeDef"], "Marker": str},
     total=False,
 )
 
@@ -622,122 +738,51 @@ JoinDomainOutputTypeDef = TypedDict(
     total=False,
 )
 
-FileShareInfoTypeDef = TypedDict(
-    "FileShareInfoTypeDef",
-    {
-        "FileShareType": Literal["NFS", "SMB"],
-        "FileShareARN": str,
-        "FileShareId": str,
-        "FileShareStatus": str,
-        "GatewayARN": str,
-    },
+ListAutomaticTapeCreationPoliciesOutputTypeDef = TypedDict(
+    "ListAutomaticTapeCreationPoliciesOutputTypeDef",
+    {"AutomaticTapeCreationPolicyInfos": List["AutomaticTapeCreationPolicyInfoTypeDef"]},
     total=False,
 )
 
 ListFileSharesOutputTypeDef = TypedDict(
     "ListFileSharesOutputTypeDef",
-    {"Marker": str, "NextMarker": str, "FileShareInfoList": List[FileShareInfoTypeDef]},
-    total=False,
-)
-
-GatewayInfoTypeDef = TypedDict(
-    "GatewayInfoTypeDef",
-    {
-        "GatewayId": str,
-        "GatewayARN": str,
-        "GatewayType": str,
-        "GatewayOperationalState": str,
-        "GatewayName": str,
-        "Ec2InstanceId": str,
-        "Ec2InstanceRegion": str,
-    },
+    {"Marker": str, "NextMarker": str, "FileShareInfoList": List["FileShareInfoTypeDef"]},
     total=False,
 )
 
 ListGatewaysOutputTypeDef = TypedDict(
-    "ListGatewaysOutputTypeDef", {"Gateways": List[GatewayInfoTypeDef], "Marker": str}, total=False
-)
-
-DiskTypeDef = TypedDict(
-    "DiskTypeDef",
-    {
-        "DiskId": str,
-        "DiskPath": str,
-        "DiskNode": str,
-        "DiskStatus": str,
-        "DiskSizeInBytes": int,
-        "DiskAllocationType": str,
-        "DiskAllocationResource": str,
-        "DiskAttributeList": List[str],
-    },
+    "ListGatewaysOutputTypeDef",
+    {"Gateways": List["GatewayInfoTypeDef"], "Marker": str},
     total=False,
 )
 
 ListLocalDisksOutputTypeDef = TypedDict(
-    "ListLocalDisksOutputTypeDef", {"GatewayARN": str, "Disks": List[DiskTypeDef]}, total=False
+    "ListLocalDisksOutputTypeDef", {"GatewayARN": str, "Disks": List["DiskTypeDef"]}, total=False
 )
 
 ListTagsForResourceOutputTypeDef = TypedDict(
     "ListTagsForResourceOutputTypeDef",
-    {"ResourceARN": str, "Marker": str, "Tags": List[TagTypeDef]},
-    total=False,
-)
-
-TapeInfoTypeDef = TypedDict(
-    "TapeInfoTypeDef",
-    {
-        "TapeARN": str,
-        "TapeBarcode": str,
-        "TapeSizeInBytes": int,
-        "TapeStatus": str,
-        "GatewayARN": str,
-        "PoolId": str,
-    },
+    {"ResourceARN": str, "Marker": str, "Tags": List["TagTypeDef"]},
     total=False,
 )
 
 ListTapesOutputTypeDef = TypedDict(
-    "ListTapesOutputTypeDef", {"TapeInfos": List[TapeInfoTypeDef], "Marker": str}, total=False
+    "ListTapesOutputTypeDef", {"TapeInfos": List["TapeInfoTypeDef"], "Marker": str}, total=False
 )
 
 ListVolumeInitiatorsOutputTypeDef = TypedDict(
     "ListVolumeInitiatorsOutputTypeDef", {"Initiators": List[str]}, total=False
 )
 
-VolumeRecoveryPointInfoTypeDef = TypedDict(
-    "VolumeRecoveryPointInfoTypeDef",
-    {
-        "VolumeARN": str,
-        "VolumeSizeInBytes": int,
-        "VolumeUsageInBytes": int,
-        "VolumeRecoveryPointTime": str,
-    },
-    total=False,
-)
-
 ListVolumeRecoveryPointsOutputTypeDef = TypedDict(
     "ListVolumeRecoveryPointsOutputTypeDef",
-    {"GatewayARN": str, "VolumeRecoveryPointInfos": List[VolumeRecoveryPointInfoTypeDef]},
-    total=False,
-)
-
-VolumeInfoTypeDef = TypedDict(
-    "VolumeInfoTypeDef",
-    {
-        "VolumeARN": str,
-        "VolumeId": str,
-        "GatewayARN": str,
-        "GatewayId": str,
-        "VolumeType": str,
-        "VolumeSizeInBytes": int,
-        "VolumeAttachmentStatus": str,
-    },
+    {"GatewayARN": str, "VolumeRecoveryPointInfos": List["VolumeRecoveryPointInfoTypeDef"]},
     total=False,
 )
 
 ListVolumesOutputTypeDef = TypedDict(
     "ListVolumesOutputTypeDef",
-    {"GatewayARN": str, "Marker": str, "VolumeInfos": List[VolumeInfoTypeDef]},
+    {"GatewayARN": str, "Marker": str, "VolumeInfos": List["VolumeInfoTypeDef"]},
     total=False,
 )
 
@@ -785,6 +830,10 @@ StartAvailabilityMonitorTestOutputTypeDef = TypedDict(
 
 StartGatewayOutputTypeDef = TypedDict("StartGatewayOutputTypeDef", {"GatewayARN": str}, total=False)
 
+UpdateAutomaticTapeCreationPolicyOutputTypeDef = TypedDict(
+    "UpdateAutomaticTapeCreationPolicyOutputTypeDef", {"GatewayARN": str}, total=False
+)
+
 UpdateBandwidthRateLimitOutputTypeDef = TypedDict(
     "UpdateBandwidthRateLimitOutputTypeDef", {"GatewayARN": str}, total=False
 )
